# Unidades de tamanho
KILOBYTE = 1024
MEGABYTE = 1024 * 1024
GIGABYTE = 1024 * 1024 * 1024
TERABYTE = 1024 * 1024 * 1024 * 1024

# Unidades de tempo
MILLISECONDS = 0.001
SECONDS = 1
MINUTES = 60 * SECONDS
HOURS = 60 * MINUTES
